@@ -107,8 +107,6 @@ if os.name == 'nt':
                     os.environ['PATH'] = oldenv
         return None
 
-
-
     base_name = 'spatialindex_c'
     if '64' in platform.architecture()[0]:
         arch = '64'
@@ -328,23 +326,25 @@ try:
     rt.Index_Flush.restype = None
     rt.Index_Flush.errcheck = check_void_done
 
-    rt.Index_Contains_obj.argtypes = [ctypes.c_void_p,
-                                      ctypes.POINTER(ctypes.c_double),
-                                      ctypes.POINTER(ctypes.c_double),
-                                      ctypes.c_uint32,
-                                      ctypes.POINTER(
-                                          ctypes.POINTER(ctypes.c_void_p)),
-                                      ctypes.POINTER(ctypes.c_uint64)]
+    rt.Index_Contains_obj.argtypes = [
+        ctypes.c_void_p,
+        ctypes.POINTER(ctypes.c_double),
+        ctypes.POINTER(ctypes.c_double),
+        ctypes.c_uint32,
+        ctypes.POINTER(ctypes.POINTER(ctypes.c_void_p)),
+        ctypes.POINTER(ctypes.c_uint64)
+    ]
     rt.Index_Contains_obj.restype = ctypes.c_int
     rt.Index_Contains_obj.errcheck = check_return
 
-    rt.Index_Contains_id.argtypes = [ctypes.c_void_p,
-                                       ctypes.POINTER(ctypes.c_double),
-                                       ctypes.POINTER(ctypes.c_double),
-                                       ctypes.c_uint32,
-                                       ctypes.POINTER(
-                                           ctypes.POINTER(ctypes.c_int64)),
-                                       ctypes.POINTER(ctypes.c_uint64)]
+    rt.Index_Contains_id.argtypes = [
+        ctypes.c_void_p,
+        ctypes.POINTER(ctypes.c_double),
+        ctypes.POINTER(ctypes.c_double),
+        ctypes.c_uint32,
+        ctypes.POINTER(ctypes.POINTER(ctypes.c_int64)),
+        ctypes.POINTER(ctypes.c_uint64)
+    ]
     rt.Index_Contains_id.restype = ctypes.c_int
     rt.Index_Contains_id.errcheck = check_return
 
